crabnet.data.benchmark\_data.aflow\_\_ael\_shear\_modulus\_vrh package
======================================================================

Module contents
---------------

.. automodule:: crabnet.data.benchmark_data.aflow__ael_shear_modulus_vrh
   :members:
   :undoc-members:
   :show-inheritance:
